@@ -6,6 +6,7 @@ from typing import TYPE_CHECKING
 from checkov.bicep.parser import Parser
 from checkov.bicep.utils import get_scannable_file_paths
 from checkov.common.graph.db_connectors.db_connector import DBConnector
+from checkov.common.graph.graph_builder.consts import GraphSource
 from checkov.common.graph.graph_manager import GraphManager
 from checkov.bicep.graph_builder.local_graph import BicepLocalGraph
 
@@ -15,7 +16,7 @@ if TYPE_CHECKING:
 
 
 class BicepGraphManager(GraphManager[BicepLocalGraph, "dict[Path, BicepJson]"]):
-    def __init__(self, db_connector: DBConnector[DiGraph], source: str = "Bicep") -> None:
+    def __init__(self, db_connector: DBConnector[DiGraph], source: str = GraphSource.BICEP) -> None:
         super().__init__(db_connector=db_connector, parser=None, source=source)
 
     def build_graph_from_source_directory(
