@@ -19,6 +19,7 @@ from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
 from checkov.common.graph.graph_builder import CustomAttributes
+from checkov.common.graph.graph_builder.consts import GraphSource
 from checkov.common.images.image_referencer import ImageReferencerMixin
 from checkov.common.output.extra_resource import ExtraResource
 from checkov.common.output.graph_record import GraphRecord
@@ -40,7 +41,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[CloudformationGraphManager])
     def __init__(
             self,
             db_connector: NetworkxConnector | None = None,
-            source: str = "CloudFormation",
+            source: str = GraphSource.CLOUDFORMATION,
             graph_class: Type[CloudformationLocalGraph] = CloudformationLocalGraph,
             graph_manager: CloudformationGraphManager | None = None,
             external_registries: list[BaseRegistry] | None = None
