@@ -215,10 +215,10 @@ class SuppressionsIntegration(BaseIntegrationFeature):
 
     def get_policy_level_suppressions(self) -> List[str]:
         policy_level_suppressions = []
-        for check_id, check_suppressions in self.suppressions.items():
+        for check_suppressions in self.suppressions.values():
             for suppression in check_suppressions:
                 if suppression.get("suppressionType") == "Policy":
-                    policy_level_suppressions.append(check_id)
+                    policy_level_suppressions.append(suppression['policyId'])
                     break
         return policy_level_suppressions
 
