@@ -3,7 +3,7 @@ from __future__ import annotations
 import logging
 import subprocess  # nosec
 from pathlib import Path
-from typing import Union, Dict, Any
+from typing import Union, Dict, Any, TYPE_CHECKING
 import asyncio
 from urllib.parse import quote_plus
 
@@ -12,6 +12,8 @@ import json
 import os
 import time
 
+from yarl import URL
+
 from checkov.common.bridgecrew.vulnerability_scanning.integrations.docker_image_scanning import \
     docker_image_scanning_integration
 from checkov.common.bridgecrew.platform_integration import bc_integration
@@ -19,6 +21,10 @@ from checkov.common.util.file_utils import decompress_file_gzip_base64
 from checkov.common.util.http_utils import request_wrapper
 from checkov.common.bridgecrew.platform_key import bridgecrew_dir
 
+if TYPE_CHECKING:
+    from aiohttp import ClientSession
+
+
 TWISTCLI_FILE_NAME = 'twistcli'
 DOCKER_IMAGE_SCAN_RESULT_FILE_NAME = 'docker-image-scan-results.json'
 CHECKOV_SEC_IN_WEEK = 604800
@@ -125,24 +131,7 @@ class ImageScanner:
                 headers=bc_integration.get_default_headers("GET"), should_call_raise_for_status=True
             )
             response_json = response.json()
-            output_type = response_json["outputType"]
-
-            logging.info(f"{output_type} returned from cache")
-
-            if output_type == "Error":
-                logging.error(response_json["outputData"])
-                return None
-
-            elif output_type == "Result":
-                result: dict[str, Any] = json.loads(
-                    decompress_file_gzip_base64(
-                        response_json["outputData"]
-                    )
-                )
-                return result
-
-            logging.info(f"Got an empty result for image={image_id}")
-            return {}
+            return ImageScanner._extract_cache_results_for_image(image_id, response_json)
 
         except Exception:
             logging.debug(
@@ -150,6 +139,45 @@ class ImageScanner:
                 "Note that the scan is still running. if it is repeated, please report.", exc_info=True)
             return None
 
+    @staticmethod
+    async def get_scan_results_from_cache_async(session: ClientSession, image_id: str) -> Dict[str, Any] | None:
+        """
+        This is an async implementation of `get_scan_results_from_cache`. The only change is we're getting a session
+        as an input, and the asyncio behavior is managed in the calling method.
+        """
+        try:
+            image_id_encode = quote_plus(image_id)
+            url = f"{bc_integration.api_url}/api/v1/vulnerabilities/scan-results/{image_id_encode}"
+            headers = bc_integration.get_default_headers("GET")
+            async with session.request("GET", URL(url, encoded=True), headers=headers) as response:
+                response_json = await response.json()
+
+            return ImageScanner._extract_cache_results_for_image(image_id, response_json)
+
+        except Exception as e:
+            logging.debug(
+                "Unexpected failure happened during retrieving image scanning result from cache. details are below.\n"
+                "Note that the scan is still running. if it is repeated, please report.", exc_info=True)
+            logging.debug(str(e))
+            return {}
+
+    @staticmethod
+    def _extract_cache_results_for_image(image_id: str, response_json: dict[str, str]) -> dict[str, Any] | None:
+        output_type = response_json["outputType"]
+        logging.info(f"{output_type} returned from cache")
+        if output_type == "Error":
+            logging.error(response_json["outputData"])
+            return None
+        elif output_type == "Result":
+            result: dict[str, Any] = json.loads(
+                decompress_file_gzip_base64(
+                    response_json["outputData"]
+                )
+            )
+            return result
+        logging.info(f"Got an empty result for image={image_id}")
+        return {}
+
     def should_download(self) -> bool:
         if not self.twistcli_path.exists():
             return True
