@@ -124,7 +124,11 @@ class BaseCheckRegistry:
                 if check.id in [x["id"] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x["id"] == check.id][0]
 
-            if runner_filter.should_run_check(check, report_type=report_type or self.report_type):
+            if runner_filter.should_run_check(
+                    check,
+                    report_type=report_type or self.report_type,
+                    file_origin_paths=[scanned_file]
+            ):
                 result = self.run_check(check, entity_configuration, entity_name, entity_type, scanned_file, skip_info)
                 results[check] = result
         return results
