@@ -3,6 +3,7 @@ from __future__ import annotations
 import concurrent.futures
 import logging
 import re
+import json
 from typing import List, Tuple, Dict, Any, Optional, Pattern, TYPE_CHECKING
 
 from bc_jsonpath_ng.ext import parse
@@ -64,6 +65,7 @@ class BaseAttributeSolver(BaseSolver):
         for attr in attr_parts:
             attr_to_check = f'{attr_to_check}.{attr}' if attr_to_check else attr
             value_to_check = vertex.get(attr_to_check)
+            value_to_check = self._render_json_str(value_to_check, attr, vertex)
 
             # we can only check is_attribute_value_check when evaluating the full attribute
             # for example, if we have a policy that says "tags.component exists", and tags = local.tags, then
@@ -176,3 +178,13 @@ class BaseAttributeSolver(BaseSolver):
         #     return True
 
         return False
+
+    @staticmethod
+    def _render_json_str(value_to_check: Any, attr: str, vertex: Dict[str, Any]) -> Any:
+        if attr == 'policy' and vertex.get('resource_type', '').endswith('policy'):
+            try:
+                value_to_check = json.loads(value_to_check)
+                return value_to_check
+            except Exception as e:
+                logging.info(f'cant parse policy str to object, {str(e)}')
+        return value_to_check
