@@ -11,10 +11,4 @@ class LessThanAttributeSolver(GreaterThanOrEqualAttributeSolver):
         if vertex.get(attribute) is None:  # type:ignore[arg-type]  # due to attribute can be None
             return False
 
-        attr_val = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
-        # if this value contains an underendered variable, then we cannot evaluate the check,
-        # so return True (since we cannot return UNKNOWN)
-        if self._is_variable_dependant(attr_val, vertex['source_']):
-            return True
-
         return not super()._get_operation(vertex, attribute)
