@@ -38,6 +38,7 @@ from checkov.common.util.json_utils import CustomJSONEncoder
 from checkov.common.util.secrets_omitter import SecretsOmitter
 from checkov.common.util.type_forcers import convert_csv_string_arg_to_list, force_list
 from checkov.sca_image.runner import Runner as image_runner
+from checkov.secrets.consts import SECRET_VALIDATION_STATUSES
 from checkov.terraform.context_parsers.registry import parser_registry
 from checkov.terraform.parser import Parser
 from checkov.terraform.runner import Runner as tf_runner
@@ -208,6 +209,8 @@ class RunnerRegistry:
                 val = val.upper()
                 if not soft_fail_threshold or Severities[val].level > soft_fail_threshold.level:
                     soft_fail_threshold = Severities[val]
+            elif val.capitalize() in SECRET_VALIDATION_STATUSES:
+                soft_fail_on_checks.append(val.capitalize())
             else:
                 soft_fail_on_checks.append(val)
 
@@ -222,6 +225,8 @@ class RunnerRegistry:
                 val = val.upper()
                 if not hard_fail_threshold or Severities[val].level < hard_fail_threshold.level:
                     hard_fail_threshold = Severities[val]
+            elif val.capitalize() in SECRET_VALIDATION_STATUSES:
+                hard_fail_on_checks.append(val.capitalize())
             else:
                 hard_fail_on_checks.append(val)
 
