@@ -8,6 +8,7 @@ from typing import List, Optional, Tuple, Union
 
 from tabulate import tabulate
 
+from checkov.ansible.checks.registry import registry as ansible_registry
 from checkov.argo_workflows.checks.registry import registry as argo_workflows_registry
 from checkov.arm.registry import arm_resource_registry, arm_parameter_registry
 from checkov.azure_pipelines.checks.registry import registry as azure_pipelines_registry
@@ -160,6 +161,11 @@ def get_checks(frameworks: Optional[List[str]] = None, use_bc_ids: bool = False,
         add_from_repository(bicep_resource_registry, "resource", "Bicep")
     if any(x in framework_list for x in ("all", "openapi")):
         add_from_repository(openapi_registry, "resource", "OpenAPI")
+    if any(x in framework_list for x in ("all", "ansible")):
+        graph_registry = get_graph_checks_registry("ansible")
+        graph_registry.load_checks()
+        add_from_repository(graph_registry, "resource", "Ansible")
+        add_from_repository(ansible_registry, "resource", "Ansible")
     if any(x in framework_list for x in ("all", "secrets")):
         for check_id, check_type in CHECK_ID_TO_SECRET_TYPE.items():
             if not filtered_policy_ids or check_id in filtered_policy_ids:
