@@ -306,10 +306,16 @@ def to_string(value: Any) -> str:
 def get_current_module_index(full_path: str) -> Optional[int]:
     hcl_index = None
     tf_index = None
-    if '.hcl' in full_path:
-        hcl_index = full_path.index('.hcl') + 4  # len('.hcl')
-    if '.tf' in full_path:
-        tf_index = full_path.index('.tf') + 3    # len('.tf')
+    if '[' not in full_path and '#' not in full_path:
+        return len(full_path)
+    if '.hcl[' in full_path:
+        hcl_index = full_path.index('.hcl[') + 4  # len('.hcl')
+    elif '.hcl#' in full_path:
+        hcl_index = full_path.index('.hcl#') + 4  # len('.hcl')
+    if '.tf[' in full_path:
+        tf_index = full_path.index('.tf[') + 3    # len('.tf')
+    elif '.tf#' in full_path:
+        tf_index = full_path.index('.tf#') + 3  # len('.tf')
     if hcl_index and tf_index:
         # returning the index of the first file
         return min(hcl_index, tf_index)
