@@ -18,6 +18,7 @@ from urllib3.exceptions import MaxRetryError
 
 import checkov.logging_init  # noqa  # should be imported before the others to ensure correct logging setup
 
+from checkov.ansible.runner import Runner as ansible_runner
 from checkov.argo_workflows.runner import Runner as argo_workflows_runner
 from checkov.arm.runner import Runner as arm_runner
 from checkov.azure_pipelines.runner import Runner as azure_pipelines_runner
@@ -31,6 +32,8 @@ from checkov.common.bridgecrew.integration_features.features.repo_config_integra
     integration as repo_config_integration
 from checkov.common.bridgecrew.integration_features.features.suppressions_integration import \
     integration as suppressions_integration
+from checkov.common.bridgecrew.integration_features.features.custom_policies_integration import \
+    integration as custom_policies_integration
 from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
 from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.bridgecrew.integration_features.features.licensing_integration import integration as licensing_integration
@@ -106,7 +109,8 @@ DEFAULT_RUNNERS = [
     sca_image_runner(),
     argo_workflows_runner(),
     circleci_pipelines_runner(),
-    azure_pipelines_runner()
+    azure_pipelines_runner(),
+    ansible_runner(),
 ]
 
 
@@ -326,8 +330,11 @@ def run(banner: str = checkov_banner, argv: list[str] = sys.argv[1:]) -> int | N
     logger.debug(f"Filtered list of policies: {runner_filter.filtered_policy_ids}")
 
     runner_filter.excluded_paths = runner_filter.excluded_paths + list(repo_config_integration.skip_paths)
-
-    runner_filter.set_suppressed_policies(suppressions_integration.get_policy_level_suppressions())
+    policy_level_suppression = suppressions_integration.get_policy_level_suppressions()
+    bc_cloned_checks = custom_policies_integration.bc_cloned_checks
+    runner_filter.bc_cloned_checks = bc_cloned_checks
+    custom_policies_integration.policy_level_suppression = policy_level_suppression
+    runner_filter.set_suppressed_policies(policy_level_suppression)
 
     if config.use_enforcement_rules:
         runner_filter.apply_enforcement_rules(repo_config_integration.code_category_configs)
@@ -757,15 +764,20 @@ class Checkov:
         bc_integration.get_prisma_build_policies(self.config.policy_metadata_filter)
 
         integration_feature_registry.run_pre_scan()
-
+        policy_level_suppression = suppressions_integration.get_policy_level_suppressions()
+        bc_cloned_checks = custom_policies_integration.bc_cloned_checks
+        runner_filter.bc_cloned_checks = bc_cloned_checks
+        custom_policies_integration.policy_level_suppression = policy_level_suppression
         runner_filter.run_image_referencer = licensing_integration.should_run_image_referencer()
-
         runner_filter.filtered_policy_ids = policy_metadata_integration.filtered_policy_ids
         logger.debug(f"Filtered list of policies: {runner_filter.filtered_policy_ids}")
 
         runner_filter.excluded_paths = runner_filter.excluded_paths + list(repo_config_integration.skip_paths)
-
-        runner_filter.set_suppressed_policies(suppressions_integration.get_policy_level_suppressions())
+        policy_level_suppression = suppressions_integration.get_policy_level_suppressions()
+        bc_cloned_checks = custom_policies_integration.bc_cloned_checks
+        runner_filter.bc_cloned_checks = bc_cloned_checks
+        custom_policies_integration.policy_level_suppression = policy_level_suppression
+        runner_filter.set_suppressed_policies(policy_level_suppression)
 
         if self.config.use_enforcement_rules:
             runner_filter.apply_enforcement_rules(repo_config_integration.code_category_configs)
