@@ -1,42 +1,22 @@
 from __future__ import annotations
 
 import os
-from typing import TYPE_CHECKING, Callable, Any
 
 from hcl2 import START_LINE as HCL_START_LINE, END_LINE as HCL_END_LINE
 
 from checkov.common.graph.graph_builder import CustomAttributes
+from checkov.common.images.graph.image_referencer_provider import GraphImageReferencerProvider
 from checkov.common.images.image_referencer import Image
 from checkov.common.util.consts import START_LINE, END_LINE
 from checkov.common.util.str_utils import removeprefix
 from checkov.terraform.graph_builder.utils import setup_file_path_to_referred_id, get_related_resource_id
 
-if TYPE_CHECKING:
-    from networkx import DiGraph
-    from typing_extensions import TypeAlias
 
-_ExtractImagesCallableAlias: TypeAlias = Callable[["dict[str, Any]"], "list[str]"]
-
-
-class BaseTerraformProvider:
-    __slots__ = ("graph_connector", "supported_resource_types")
-
-    def __init__(
-        self, graph_connector: DiGraph, supported_resource_types: dict[str, _ExtractImagesCallableAlias]
-    ) -> None:
-        self.graph_connector = graph_connector
-        self.supported_resource_types = supported_resource_types
+class BaseTerraformProvider(GraphImageReferencerProvider):
 
     def extract_images_from_resources(self) -> list[Image]:
         images = []
-
-        resource_nodes = [
-            node
-            for node, resource_type in self.graph_connector.nodes(data=CustomAttributes.RESOURCE_TYPE)
-            if resource_type and resource_type in self.supported_resource_types
-        ]
-
-        supported_resources_graph = self.graph_connector.subgraph(resource_nodes)
+        supported_resources_graph = self.extract_nodes()
         file_path_to_referred_id = setup_file_path_to_referred_id(self.graph_connector)
 
         for _, resource in supported_resources_graph.nodes(data=True):
