@@ -13,6 +13,7 @@ import dpath.util
 from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
+from checkov.common.graph.graph_builder.consts import GraphSource
 from checkov.common.images.image_referencer import ImageReferencerMixin
 from checkov.common.output.extra_resource import ExtraResource
 from checkov.common.parallelizer.parallel_runner import parallel_runner
@@ -64,7 +65,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
         parser: Parser | None = None,
         db_connector: NetworkxConnector | None = None,
         external_registries: list[BaseRegistry] | None = None,
-        source: str = "Terraform",
+        source: str = GraphSource.TERRAFORM,
         graph_class: type[TerraformLocalGraph] = TerraformLocalGraph,
         graph_manager: TerraformGraphManager | None = None
     ) -> None:
@@ -555,7 +556,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
             return
 
         for definition in resolved_paths:
-            for block_type, block_configs in definition_context[definition].items():
+            for block_type, block_configs in definition_context.get(definition, {}).items():
                 # skip if type is not a Terraform resource
                 if block_type not in CHECK_BLOCK_TYPES:
                     continue
